=== modified file 'Makefile'
--- Makefile	2009-01-06 05:10:34 +0000
+++ Makefile	2009-01-06 22:51:38 +0000
@@ -76,7 +76,7 @@
 PLUGINS=plugins.d/password-prompt plugins.d/mandos-client \
 	plugins.d/usplash plugins.d/splashy plugins.d/askpass-fifo
 CPROGS=plugin-runner $(PLUGINS)
-PROGS=mandos mandos-keygen $(CPROGS)
+PROGS=mandos mandos-keygen mandos-list $(CPROGS)
 DOCS=mandos.8 plugin-runner.8mandos mandos-keygen.8 \
 	plugins.d/mandos-client.8mandos \
 	plugins.d/password-prompt.8mandos mandos.conf.5 \
@@ -163,6 +163,11 @@
 		--expression='s/^\(VERSION="\)[^"]*"$$/\1$(version)"/' \
 		$@
 
+mandos-list: Makefile
+	$(SED) --in-place \
+		--expression='s/^\(version = "\)[^"]*"$$/\1$(version)"/' \
+		$@
+
 mandos.lsm: Makefile
 	$(SED) --in-place \
 		--expression='s/^\(Version:\).*/\1\t$(version)/' \
@@ -170,6 +175,9 @@
 	$(SED) --in-place \
 		--expression='s/^\(Entered-date:\).*/\1\t$(shell date --rfc-3339=date --reference=Makefile)/' \
 		$@
+	$(SED) --in-place \
+		--expression='s/\(mandos_\)[0-9.]\+\(\.orig\.tar\.gz\)/\1$(version)\2/' \
+		$@
 
 plugins.d/mandos-client: plugins.d/mandos-client.o
 	$(LINK.o) $(GNUTLS_LIBS) $(AVAHI_LIBS) $(GPGME_LIBS) \

=== modified file 'mandos'
--- mandos	2009-01-06 05:10:34 +0000
+++ mandos	2009-01-06 02:42:53 +0000
@@ -35,7 +35,7 @@
 
 import SocketServer
 import socket
-import optparse
+from optparse import OptionParser
 import datetime
 import errno
 import gnutls.crypto
@@ -889,7 +889,7 @@
 
 
 def main():
-    parser = optparse.OptionParser(version = "%%prog %s" % version)
+    parser = OptionParser(version = "%%prog %s" % version)
     parser.add_option("-i", "--interface", type="string",
                       metavar="IF", help="Bind to interface IF")
     parser.add_option("-a", "--address", type="string",
@@ -911,7 +911,8 @@
                       " files")
     parser.add_option("--no-dbus", action="store_false",
                       dest="use_dbus",
-                      help=optparse.SUPPRESS_HELP)
+                      help="Do not provide D-Bus system bus"
+                      " interface")
     options = parser.parse_args()[0]
     
     if options.check:
@@ -957,7 +958,6 @@
     # For convenience
     debug = server_settings["debug"]
     use_dbus = server_settings["use_dbus"]
-    use_dbus = False
     
     if not debug:
         syslogger.setLevel(logging.WARNING)

=== added file 'mandos-list'
--- mandos-list	1970-01-01 00:00:00 +0000
+++ mandos-list	2008-12-21 19:19:25 +0000
@@ -0,0 +1,65 @@
+#!/usr/bin/python
+# -*- mode: python; coding: utf-8 -*-
+
+import dbus
+from optparse import OptionParser
+import locale
+
+locale.setlocale(locale.LC_ALL, u'')
+
+tablewords = {
+    'name': u'Name',
+    'enabled': u'Enabled',
+    'timeout': u'Timeout',
+    'last_checked_ok': u'Last Successful Check',
+    'created': u'Created',
+    'interval': u'Interval',
+    'host': u'Host',
+    'fingerprint': u'Fingerprint',
+    'checker_running': u'Check Is Running',
+    'last_enabled': u'Last Enabled',
+    'checker': u'Checker',
+    }
+busname = 'org.mandos-system.Mandos'
+object_path = '/Mandos'
+interface = 'org.mandos_system.Mandos'
+version = "1.0.2"
+defaultkeywords = ('name', 'enabled', 'timeout', 'last_checked_ok',
+                   'checker')
+
+parser = OptionParser(version = "%%prog %s" % version)
+parser.add_option("-a", "--all", action="store_true", default=False,
+                  help="Print all fields")
+options = parser.parse_args()[0]
+if options.all:
+    keywords = ('name', 'enabled', 'timeout', 'last_checked_ok',
+                'created', 'interval', 'host', 'fingerprint',
+                'checker_running', 'last_enabled', 'checker')
+else:
+    keywords = defaultkeywords
+
+
+bus = dbus.SystemBus()
+mandos_dbus_objc = bus.get_object(busname, object_path)
+mandos_serv = dbus.Interface(mandos_dbus_objc,
+                             dbus_interface = interface)
+mandos_clients = mandos_serv.GetAllClientsWithProperties()
+
+def valuetostring(x):
+    if type(x) is dbus.Boolean:
+        return u"Yes" if x else u"No"
+    else:
+        return unicode(x)
+
+format_string = u' '.join(u'%%-%ds'
+                         % max(len(tablewords[key]),
+                               max(len(valuetostring(client[key]))
+                                   for client
+                                   in mandos_clients.itervalues()))
+                         for key in keywords)
+print format_string % tuple(tablewords[key] for key in keywords) 
+for client in mandos_clients.itervalues():
+    print format_string % tuple(valuetostring(client[key])
+                                for key in keywords)
+
+

=== modified file 'mandos.xml'
--- mandos.xml	2009-01-05 23:26:06 +0000
+++ mandos.xml	2009-01-04 21:54:55 +0000
@@ -85,6 +85,8 @@
       <replaceable>DIRECTORY</replaceable></option></arg>
       <sbr/>
       <arg><option>--debug</option></arg>
+      <sbr/>
+      <arg><option>--no-dbus</option></arg>
     </cmdsynopsis>
     <cmdsynopsis>
       <command>&COMMANDNAME;</command>
@@ -229,6 +231,16 @@
 	  </para>
 	</listitem>
       </varlistentry>
+      
+      <varlistentry>
+	<term><option>--no-dbus</option></term>
+	<listitem>
+	  <xi:include href="mandos-options.xml" xpointer="dbus"/>
+	  <para>
+	    See also <xref linkend="dbus_interface"/>.
+	  </para>
+	</listitem>
+      </varlistentry>
     </variablelist>
   </refsect1>
   
@@ -324,6 +336,16 @@
     </para>
   </refsect1>
   
+  <refsect1 id="dbus_interface">
+    <title>D-BUS INTERFACE</title>
+    <para>
+      The server will by default provide a D-Bus system bus interface.
+      This interface will only be accessible by the root user or a
+      Mandos-specific user, if such a user exists.
+      <!-- XXX -->
+    </para>
+  </refsect1>
+
   <refsect1 id="exit_status">
     <title>EXIT STATUS</title>
     <para>

=== modified file 'plugin-runner.c'
--- plugin-runner.c	2009-01-04 21:54:55 +0000
+++ plugin-runner.c	2009-01-06 22:49:50 +0000
@@ -309,6 +309,7 @@
   struct stat st;
   fd_set rfds_all;
   int ret, maxfd = 0;
+  ssize_t sret;
   uid_t uid = 65534;
   gid_t gid = 65534;
   bool debug = false;
@@ -546,7 +547,6 @@
     char *org_line = NULL;
     char *p, *arg, *new_arg, *line;
     size_t size = 0;
-    ssize_t sret;
     const char whitespace_delims[] = " \r\t\f\v\n";
     const char comment_delim[] = "#";
 
@@ -1019,18 +1019,18 @@
 	proc->buffer_size += BUFFER_SIZE;
       }
       /* Read from the process */
-      ret = read(proc->fd, proc->buffer + proc->buffer_length,
-		 BUFFER_SIZE);
-      if(ret < 0){
+      sret = read(proc->fd, proc->buffer + proc->buffer_length,
+		  BUFFER_SIZE);
+      if(sret < 0){
 	/* Read error from this process; ignore the error */
 	proc = proc->next;
 	continue;
       }
-      if(ret == 0){
+      if(sret == 0){
 	/* got EOF */
 	proc->eof = true;
       } else {
-	proc->buffer_length += (size_t) ret;
+	proc->buffer_length += (size_t) sret;
       }
     }
   }

